@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -35,15 +35,14 @@ public:
 
     void loadTemplate(const QString &fileName);
 
-    QString exportedFileInfo();
+    QString exportedFileInfo() const;
     void removeNotSelectedItems();
-private Q_SLOTS:
+private:
     void slotSelectAll();
     void slotUnselectAll();
 
     void slotSaveAsTemplate();
     void slotLoadTemplate();
-private:
     void readConfig();
     void writeConfig();
     void loadDefaultTemplate();
